@@ -13,13 +13,11 @@
 #include "rt_nonfinite.h"
 #include "MAVEfast.h"
 #include "MAVEfast_initialize.h"
-#include "MAVEfast_data.h"
 
 /* Function Definitions */
 void MAVEfast_initialize()
 {
   rt_InitInfAndNaN(8U);
-//  omp_init_nest_lock(&emlrtNestLockGlobal);
 }
 
 /* End of code generation (MAVEfast_initialize.cpp) */
