@@ -20,12 +20,11 @@
 #include <string.h>
 #include "rt_nonfinite.h"
 #include "rtwtypes.h"
-//#include "omp.h"
 #include "MAVEfast_types.h"
 
 /* Function Declarations */
-extern void b_sqrt(creal_T *x);
-extern void c_sqrt(emxArray_real_T *x);
+extern void b_sqrt(emxArray_real_T *x);
+extern void c_sqrt(creal_T *x);
 extern void d_sqrt(emxArray_real_T *x);
 
 #endif
